# GNU Enterprise Forms - Curses UI Driver - Scrollbar Widget
#
# Copyright 2000-2005 Free Software Foundation
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: scrollbar.py 7961 2005-09-22 04:24:33Z reinhard $

from _base import UIHelper

# =============================================================================
# Scrollbar class (stub - no scrollbars for curses)
# =============================================================================

class UIScrollBar (UIHelper):

  def _init (self, index):
    pass

  def adjustScrollbar (self, position, count):
    pass

# =============================================================================
# Configuration data
# =============================================================================

configuration = {
  'baseClass'  : UIScrollBar,
  'provides'   : 'GFScrollBar',
  'container'  : 0,
  }
